@@ -5,8 +5,6 @@
 #include <functional>
 #include <netdb.h>
 #include <unistd.h>
-#include <rak/file_stat.h>
-#include <rak/path.h>
 #include <rak/string_manip.h>
 #include <rak/regex.h>
 #include <torrent/rate.h>
@@ -21,13 +19,14 @@
 #include <torrent/net/types.h>
 #include <torrent/peer/connection_list.h>
 #include <torrent/peer/peer_list.h>
+#include <torrent/utils/file_stat.h>
 #include <torrent/utils/log.h>
 #include <torrent/utils/option_strings.h>
 
 #include "core/download.h"
-#include "core/download_store.h"
 #include "core/manager.h"
 #include "rpc/parse.h"
+#include "session/session_manager.h"
 
 #include "globals.h"
 #include "control.h"
@@ -77,23 +76,23 @@ apply_d_change_link(core::Download* download, const torrent::Object::list_type&
 
   if (type == "base_path") {
     target = rpc::call_command_string("d.base_path", rpc::make_target(download));
-    link = rak::path_expand(prefix + rpc::call_command_string("d.base_path", rpc::make_target(download)) + postfix);
+    link   = expand_path(prefix + rpc::call_command_string("d.base_path", rpc::make_target(download)) + postfix);
 
   } else if (type == "base_filename") {
     target = rpc::call_command_string("d.base_path", rpc::make_target(download));
-    link = rak::path_expand(prefix + rpc::call_command_string("d.base_filename", rpc::make_target(download)) + postfix);
+    link   = expand_path(prefix + rpc::call_command_string("d.base_filename", rpc::make_target(download)) + postfix);
 
 //   } else if (type == "directory_path") {
 //     target = rpc::call_command_string("d.directory", rpc::make_target(download));
 //     link = rak::path_expand(prefix + rpc::call_command_string("d.base_path", rpc::make_target(download)) + postfix);
 
   } else if (type == "tied") {
-    link = rak::path_expand(rpc::call_command_string("d.tied_to_file", rpc::make_target(download)));
+    link = expand_path(rpc::call_command_string("d.tied_to_file", rpc::make_target(download)));
 
     if (link.empty())
       return torrent::Object();
 
-    link = rak::path_expand(prefix + link + postfix);
+    link = expand_path(prefix + link + postfix);
     target = rpc::call_command_string("d.base_path", rpc::make_target(download));
 
   } else {
@@ -109,7 +108,7 @@ apply_d_change_link(core::Download* download, const torrent::Object::list_type&
 
   case 1:
   {
-    rak::file_stat fileStat;
+    torrent::utils::FileStat fileStat;
     errno = 0;
 
     if (!fileStat.update_link(link) || !fileStat.is_link() || unlink(link.c_str()) == -1)
@@ -131,7 +130,7 @@ apply_d_delete_tied(core::Download* download) {
   if (tie.empty())
     return torrent::Object();
 
-  if (::unlink(rak::path_expand(tie).c_str()) == -1)
+  if (::unlink(expand_path(tie).c_str()) == -1)
     control->core()->push_log_std("Could not unlink tied file: " + std::string(std::strerror(errno)));
 
   rpc::call_command("d.tied_to_file.set", std::string(), rpc::make_target(download));
@@ -302,7 +301,7 @@ apply_d_add_peer(core::Download* download, const std::string& arg) {
   if (port < 1 || port > 65535)
     throw torrent::input_error("Invalid port number.");
 
-  assert(std::this_thread::get_id() == torrent::main_thread::thread()->thread_id());
+  assert(std::this_thread::get_id() == torrent::main_thread::thread_id());
 
   // Currently discarding SOCK_STREAM.
   torrent::this_thread::resolver()->resolve_preferred(NULL, host, AF_UNSPEC, AF_INET, [download, port](torrent::c_sa_shared_ptr sa, int err) {
@@ -495,6 +494,19 @@ download_get_variable(core::Download* download, const char* first_key, const cha
   return download->bencode()->get_key(first_key).get_key(second_key);
 }
 
+torrent::Object
+download_get_value_or_zero(core::Download* download, const char* first_key, const char* second_key = NULL) {
+  auto object = download_get_variable(download, first_key, second_key);
+
+  if (object.is_empty())
+    return int64_t(0);
+
+  if (!object.is_value())
+    throw torrent::bencode_error("Download variable is not a value.");
+
+  return object;
+}
+
 torrent::Object
 download_set_variable(core::Download* download, const torrent::Object& rawArgs, const char* first_key, const char* second_key = NULL) {
   if (second_key == NULL)
@@ -600,12 +612,16 @@ d_list_remove(core::Download* download, const torrent::Object& rawArgs, const ch
 
 #define CMD2_DL_TIMESTAMP(key, first_key, second_key)                   \
   CMD2_DL(key, std::bind(&download_get_variable, std::placeholders::_1, first_key, second_key)); \
-  CMD2_DL_VALUE_P(key ".set", std::bind(&download_set_variable_value, \
-                                             std::placeholders::_1, std::placeholders::_2, \
-                                             first_key, second_key)); \
+  CMD2_DL_VALUE_P(key ".set", std::bind(&download_set_variable_value,   \
+                                        std::placeholders::_1, std::placeholders::_2, \
+                                        first_key, second_key));        \
   CMD2_DL_VALUE_P(key ".set_if_z", std::bind(&download_set_variable_value_ifz, \
                                              std::placeholders::_1, std::placeholders::_2, \
                                              first_key, second_key));   \
+  CMD2_DL(key ".or_zero", [](core::Download* download, auto) {          \
+      return download_get_value_or_zero(download, first_key, second_key); }); \
+  CMD2_DL_VALUE(key ".elapsed", [](core::Download* download, auto value) { \
+      return download_get_value_or_zero(download, first_key, second_key).as_value() > value; });
 
 #define CMD2_DL_VAR_STRING(key, first_key, second_key)                   \
   CMD2_DL(key, std::bind(&download_get_variable, std::placeholders::_1, first_key, second_key)); \
@@ -683,8 +699,8 @@ initialize_command_download() {
   CMD2_DL_V       ("d.erase",      std::bind(&core::DownloadList::erase_ptr, control->core()->download_list(), std::placeholders::_1));
   CMD2_DL_V       ("d.check_hash", std::bind(&core::DownloadList::check_hash, control->core()->download_list(), std::placeholders::_1));
 
-  CMD2_DL         ("d.save_resume",       std::bind(&core::DownloadStore::save_resume, control->core()->download_store(), std::placeholders::_1));
-  CMD2_DL         ("d.save_full_session", std::bind(&core::DownloadStore::save_full, control->core()->download_store(), std::placeholders::_1));
+  CMD2_DL_V       ("d.save_resume",       [](core::Download* download, auto) { session_thread::manager()->save_resume_download(download); });
+  CMD2_DL_V       ("d.save_full_session", [](core::Download* download, auto) { session_thread::manager()->save_full_download(download); });
 
   CMD2_DL_V       ("d.update_priorities", CMD2_ON_DL(update_priorities));
 
