@@ -1,11 +1,10 @@
 #include "config.h"
 
+#include <cerrno>
 #include <fcntl.h>
 #include <functional>
 #include <stdio.h>
 #include <unistd.h>
-#include <rak/path.h>
-#include <rak/error_number.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <torrent/torrent.h>
@@ -171,8 +170,8 @@ cmd_file_append(const torrent::Object::list_type& args) {
 
   FILE* output = fopen(args.front().as_string().c_str(), "a");
 
-  if (output == NULL)
-    throw torrent::input_error("Could not append to file '" + args.front().as_string() + "': " + rak::error_number::current().c_str());
+  if (output == nullptr)
+    throw torrent::input_error("Could not append to file '" + args.front().as_string() + "': " + std::strerror(errno));
 
   file_print_list(++args.begin(), args.end(), output, file_print_delim_space);
 
