@@ -14,12 +14,12 @@
 #include "core/download.h"
 #include "core/download_list.h"
 #include "core/manager.h"
-#include "rak/path.h"
 #include "rpc/parse_commands.h"
 
 static const int log_flag_use_gz = 0x1;
 static const int log_flag_append_pid = 0x2;
 static const int log_flag_append_file = 0x4;
+static const int log_flag_flush = 0x8;
 
 void
 log_add_group_output_str(const char* group_name, const char* output_id) {
@@ -34,8 +34,8 @@ apply_log_open(int output_flags, const torrent::Object::list_type& args) {
 
   torrent::Object::list_const_iterator itr = args.begin();
 
-  std::string output_id = (itr++)->as_string();
-  std::string file_name = rak::path_expand((itr++)->as_string());
+  auto output_id = (itr++)->as_string();
+  auto file_name = expand_path((itr++)->as_string());
 
   if ((output_flags & log_flag_append_pid)) {
     char buffer[32];
@@ -45,11 +45,12 @@ apply_log_open(int output_flags, const torrent::Object::list_type& args) {
   }
 
   bool append = (output_flags & log_flag_append_file);
+  bool flush = (output_flags & log_flag_flush);
 
   if ((output_flags & log_flag_use_gz))
     torrent::log_open_gz_file_output(output_id.c_str(), file_name.c_str(), append);
   else
-    torrent::log_open_file_output(output_id.c_str(), file_name.c_str(), append);
+    torrent::log_open_file_output(output_id.c_str(), file_name.c_str(), append, flush);
 
   while (itr != args.end())
     log_add_group_output_str((itr++)->as_string().c_str(), output_id.c_str());
@@ -85,7 +86,7 @@ apply_log(const torrent::Object::string_type& arg, int logType) {
   }
 
   if (!arg.empty()) {
-    int logFd = open(rak::path_expand(arg).c_str(), O_WRONLY | O_APPEND | O_CREAT, 0644);
+    int logFd = open(expand_path(arg).c_str(), O_WRONLY | O_APPEND | O_CREAT, 0644);
 
     if (logFd < 0)
       throw torrent::input_error("Could not open execute log file.");
@@ -127,12 +128,14 @@ log_vmmap_dump(const std::string& str) {
 
 void
 initialize_command_logging() {
-  CMD2_ANY_LIST    ("log.open_file",        std::bind(&apply_log_open, 0, std::placeholders::_2));
-  CMD2_ANY_LIST    ("log.open_gz_file",     std::bind(&apply_log_open, log_flag_use_gz, std::placeholders::_2));
-  CMD2_ANY_LIST    ("log.open_file_pid",    std::bind(&apply_log_open, log_flag_append_pid, std::placeholders::_2));
-  CMD2_ANY_LIST    ("log.open_gz_file_pid", std::bind(&apply_log_open, log_flag_append_pid | log_flag_use_gz, std::placeholders::_2));
-  CMD2_ANY_LIST    ("log.append_file",      std::bind(&apply_log_open, log_flag_append_file, std::placeholders::_2));
-  CMD2_ANY_LIST    ("log.append_gz_file",   std::bind(&apply_log_open, log_flag_append_file, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.open_file",          std::bind(&apply_log_open, 0, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.open_file.flush",    std::bind(&apply_log_open, log_flag_flush, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.open_gz_file",       std::bind(&apply_log_open, log_flag_use_gz, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.open_file_pid",      std::bind(&apply_log_open, log_flag_append_pid, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.open_gz_file_pid",   std::bind(&apply_log_open, log_flag_append_pid | log_flag_use_gz, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.append_file",        std::bind(&apply_log_open, log_flag_append_file, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.append_file.flush",  std::bind(&apply_log_open, log_flag_append_file | log_flag_flush, std::placeholders::_2));
+  CMD2_ANY_LIST    ("log.append_gz_file",     std::bind(&apply_log_open, log_flag_append_file, std::placeholders::_2));
 
   CMD2_ANY_STRING_V("log.close",            std::bind(&torrent::log_close_output_str, std::placeholders::_2));
 
