@@ -4,8 +4,8 @@
 #include <cstdio>
 #include <netdb.h>
 #include <torrent/net/network_config.h>
-#include <torrent/net/network_manager.h>
 #include <torrent/net/resolver.h>
+#include <torrent/runtime/network_manager.h>
 #include <torrent/tracker/dht_controller.h>
 #include <torrent/tracker/tracker.h>
 #include <torrent/utils/log.h>
@@ -28,9 +28,6 @@ tracker_set_enabled(torrent::tracker::Tracker* tracker, bool state) {
 
 torrent::Object
 apply_dht_add_node(const std::string& arg) {
-  if (!torrent::runtime::network_manager()->is_dht_valid())
-    throw torrent::input_error("DHT not enabled.");
-
   int port;
   char dummy;
   char host[1024];
@@ -59,7 +56,7 @@ apply_dht_add_node(const std::string& arg) {
       }
 
       lt_log_print(torrent::LOG_DHT_CONTROLLER, "dht.add_node : %s", host_str.c_str());
-      torrent::runtime::network_manager()->dht_add_peer_node(sa.get(), port);
+      torrent::runtime::network_manager()->dht_add_bootstrap_node(host_str.c_str(), port);
   });
 
   return torrent::Object();
