@@ -1,5 +1,7 @@
 #include "config.h"
 
+#include "core/manager.h"
+
 #include <cstdio>
 #include <cstring>
 #include <fstream>
@@ -8,7 +10,6 @@
 #include <sys/select.h>
 #include <rak/address_info.h>
 #include <rak/regex.h>
-#include <rak/path.h>
 #include <rak/string_manip.h>
 #include <torrent/utils/resume.h>
 #include <torrent/object.h>
@@ -19,8 +20,8 @@
 #include <torrent/throttle.h>
 #include <torrent/net/http_stack.h>
 #include <torrent/net/network_config.h>
-#include <torrent/net/network_manager.h>
 #include <torrent/net/socket_address.h>
+#include <torrent/runtime/network_manager.h>
 #include <torrent/utils/log.h>
 
 #include "rpc/parse_commands.h"
@@ -33,7 +34,6 @@
 #include "core/download.h"
 #include "core/download_factory.h"
 #include "core/http_queue.h"
-#include "core/manager.h"
 #include "core/view.h"
 
 namespace core {
@@ -257,7 +257,7 @@ Manager::try_create_download(const std::string& uri, int flags, const command_li
       !is_network_uri(uri) &&
       !is_magnet_uri(uri) &&
       !is_data_uri(uri) &&
-      !file_status_cache()->insert(uri, 0))
+      !file_status_cache()->insert(uri))
     return;
 
   // Adding download.
