@@ -13,7 +13,6 @@
 #include <torrent/net/fd.h>
 #include <torrent/utils/chrono.h>
 #include <torrent/utils/log.h>
-#include <rak/error_number.h>
 
 #ifdef HAVE_BACKTRACE
 #include <execinfo.h>
@@ -22,17 +21,19 @@
 #include "core/dht_manager.h"
 #include "core/download.h"
 #include "core/download_factory.h"
-#include "core/download_store.h"
 #include "core/manager.h"
 #include "display/canvas.h"
 #include "display/window.h"
 #include "display/manager.h"
 #include "input/bindings.h"
-#include "ui/root.h"
-
 #include "rpc/command_scheduler.h"
 #include "rpc/command_scheduler_item.h"
 #include "rpc/parse_commands.h"
+#include "scgi/thread_scgi.h"
+#include "session/download_storer.h"
+#include "session/thread_session.h"
+#include "session/session_manager.h"
+#include "ui/root.h"
 #include "utils/directory.h"
 
 #include "control.h"
@@ -41,8 +42,6 @@
 #include "signal_handler.h"
 #include "option_parser.h"
 
-#include "thread_worker.h"
-
 #define LT_LOG(log_fmt, ...)                                    \
   lt_log_print(torrent::LOG_SYSTEM, "system: " log_fmt, __VA_ARGS__);
 
@@ -113,7 +112,7 @@ initialize_rpc_slots() {
 
 void
 load_session_torrents() {
-  utils::Directory entries = control->core()->download_store()->get_formated_entries();
+  utils::Directory entries = session::DownloadStorer::get_formated_entries(session_thread::manager()->path());
 
   for (const auto& entry : entries) {
     // We don't really support session torrents that are links. These
@@ -215,9 +214,8 @@ main(int argc, char** argv) {
     torrent::initialize();
     torrent::set_main_thread_slots(std::bind(&client_perform));
 
-    // TODO: Move to controller.
-    worker_thread = new ThreadWorker();
-    worker_thread->init_thread();
+    scgi::ThreadScgi::create_thread();
+    session::ThreadSession::create_thread();
 
     // Initialize option handlers after libtorrent to ensure
     // torrent::ConnectionManager* are valid etc.
@@ -530,13 +528,13 @@ main(int argc, char** argv) {
     return -1;
   }
 
-  torrent::log_cleanup();
-
   delete control;
   control = nullptr;
 
-  delete worker_thread;
-  worker_thread = nullptr;
+  scgi::ThreadScgi::destroy_thread();
+  session::ThreadSession::destroy_thread();
+
+  torrent::log_cleanup();
 
   return 0;
 }
@@ -565,7 +563,7 @@ handle_sigbus(int signum, siginfo_t* sa, [[maybe_unused]] void* ptr) {
 #else
   output << "Stack dump not enabled." << std::endl;
 #endif
-  output << std::endl << "Error: " << rak::error_number(sa->si_errno).c_str() << std::endl;
+  output << std::endl << "Error: " << std::strerror(sa->si_errno) << std::endl;
 
   const char* signal_reason;
 
